==> ui-hub-0.0.6.tgz: package/es/modal/modal.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import cn from 'classnames';
import CloseOutlined from '@ant-design/icons/CloseOutlined';
import FadeIn from '../fade/fadeIn';
import { defaultPrefixCls } from '../_config/dict';
;
;

function Modal(props) {
  var className = props.className,
      width = props.width,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? true : _props$visible,
      _props$mask = props.mask,
      mask = _props$mask === void 0 ? true : _props$mask,
      _props$maskClosable = props.maskClosable,
      maskClosable = _props$maskClosable === void 0 ? false : _props$maskClosable,
      _props$confirmCareful = props.confirmCareful,
      confirmCareful = _props$confirmCareful === void 0 ? false : _props$confirmCareful,
      _props$closeCorner = props.closeCorner,
      closeCorner = _props$closeCorner === void 0 ? false : _props$closeCorner,
      _props$confirmable = props.confirmable,
      confirmable = _props$confirmable === void 0 ? true : _props$confirmable,
      _props$hideDestroy = props.hideDestroy,
      hideDestroy = _props$hideDestroy === void 0 ? true : _props$hideDestroy,
      _props$okText = props.okText,
      okText = _props$okText === void 0 ? '确定' : _props$okText,
      _props$cancelText = props.cancelText,
      cancelText = _props$cancelText === void 0 ? '取消' : _props$cancelText,
      title = props.title,
      footer = props.footer,
      customStructure = props.customStructure,
      children = props.children,
      _props$prefixCls = props.prefixCls,
      prefixCls = _props$prefixCls === void 0 ? defaultPrefixCls : _props$prefixCls,
      onOk = props.onOk,
      onCancel = props.onCancel,
      onShow = props.onShow,
      onHide = props.onHide,
      restProps = _objectWithoutProperties(props, ["className", "width", "visible", "mask", "maskClosable", "confirmCareful", "closeCorner", "confirmable", "hideDestroy", "okText", "cancelText", "title", "footer", "customStructure", "children", "prefixCls", "onOk", "onCancel", "onShow", "onHide"]);

  var onClickMask = function onClickMask(e) {
    if (maskClosable) {
      typeof onCancel === 'function' && onCancel(e);
    }
  };

  var renderFooter = function renderFooter() {
    if (footer === null) {
      return null;
    }

    var okBtn = /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-button ").concat(prefixCls, "-modal-ok"),
      onClick: onOk
    }, okText);
    var cancelBtn = /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-button ").concat(prefixCls, "-modal-cancel"),
      onClick: onCancel
    }, cancelText);
    return /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-footer")
    }, footer || (confirmCareful ? /*#__PURE__*/React.createElement(React.Fragment, null, Boolean(confirmable) && okBtn, cancelBtn) : /*#__PURE__*/React.createElement(React.Fragment, null, cancelBtn, Boolean(confirmable) && okBtn)));
  };

  var renderedCloseCorner = function renderedCloseCorner() {
    if (closeCorner) {
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-modal-corner-close"),
        onClick: onCancel
      }, /*#__PURE__*/React.createElement(CloseOutlined, null));
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(FadeIn, {
    show: visible,
    needDestroy: hideDestroy,
    limitTstProperty: true,
    onShow: onShow,
    onHide: onHide
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: cn("".concat(prefixCls, "-modal"), className)
  }, restProps), !!mask && /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-mask"),
    onClick: onClickMask
  }), customStructure ? /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-custom-content")
  }, typeof children === 'function' ? children(onOk, onCancel) : children, renderedCloseCorner()) : /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-modal-content"), _defineProperty({}, "".concat(prefixCls, "-modal-content-no-title"), !title)),
    style: width ? {
      width: width
    } : undefined
  }, !!title && /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-header")
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-body")
  }, children), renderFooter(), renderedCloseCorner())));
}

export default Modal;

==> ui-hub-0.0.9.tgz: package/es/modal/modal.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import cn from 'classnames';
import Close90Outlined from '../_icon/Close90Outlined';
import FadeIn from '../fade/fadeIn';
import { defaultPrefixCls } from '../_config/dict';
;
;

function Modal(props) {
  var className = props.className,
      width = props.width,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? true : _props$visible,
      _props$mask = props.mask,
      mask = _props$mask === void 0 ? true : _props$mask,
      _props$maskClosable = props.maskClosable,
      maskClosable = _props$maskClosable === void 0 ? false : _props$maskClosable,
      _props$confirmCareful = props.confirmCareful,
      confirmCareful = _props$confirmCareful === void 0 ? false : _props$confirmCareful,
      _props$closeCorner = props.closeCorner,
      closeCorner = _props$closeCorner === void 0 ? false : _props$closeCorner,
      _props$confirmable = props.confirmable,
      confirmable = _props$confirmable === void 0 ? true : _props$confirmable,
      _props$hideDestroy = props.hideDestroy,
      hideDestroy = _props$hideDestroy === void 0 ? true : _props$hideDestroy,
      _props$okText = props.okText,
      okText = _props$okText === void 0 ? '确定' : _props$okText,
      _props$cancelText = props.cancelText,
      cancelText = _props$cancelText === void 0 ? '取消' : _props$cancelText,
      title = props.title,
      footer = props.footer,
      customStructure = props.customStructure,
      children = props.children,
      _props$prefixCls = props.prefixCls,
      prefixCls = _props$prefixCls === void 0 ? defaultPrefixCls : _props$prefixCls,
      onOk = props.onOk,
      onCancel = props.onCancel,
      onShow = props.onShow,
      onHide = props.onHide,
      restProps = _objectWithoutProperties(props, ["className", "width", "visible", "mask", "maskClosable", "confirmCareful", "closeCorner", "confirmable", "hideDestroy", "okText", "cancelText", "title", "footer", "customStructure", "children", "prefixCls", "onOk", "onCancel", "onShow", "onHide"]);

  var onClickMask = function onClickMask(e) {
    if (maskClosable) {
      typeof onCancel === 'function' && onCancel(e);
    }
  };

  var renderFooter = function renderFooter() {
    if (footer === null) {
      return null;
    }

    var okBtn = /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-button ").concat(prefixCls, "-modal-ok"),
      onClick: onOk
    }, okText);
    var cancelBtn = /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-button ").concat(prefixCls, "-modal-cancel"),
      onClick: onCancel
    }, cancelText);
    return /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-footer")
    }, footer || (confirmCareful ? /*#__PURE__*/React.createElement(React.Fragment, null, Boolean(confirmable) && okBtn, cancelBtn) : /*#__PURE__*/React.createElement(React.Fragment, null, cancelBtn, Boolean(confirmable) && okBtn)));
  };

  var renderedCloseCorner = function renderedCloseCorner() {
    if (closeCorner) {
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-modal-corner-close"),
        onClick: onCancel
      }, typeof closeCorner === 'boolean' ? /*#__PURE__*/React.createElement(Close90Outlined, null) : closeCorner);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(FadeIn, {
    show: visible,
    needDestroy: hideDestroy,
    limitTstProperty: true,
    onShow: onShow,
    onHide: onHide
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: cn("".concat(prefixCls, "-modal"), className)
  }, restProps), !!mask && /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-mask"),
    onClick: onClickMask
  }), customStructure ? /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-custom-content")
  }, typeof children === 'function' ? children(onOk, onCancel) : children, renderedCloseCorner()) : /*#__PURE__*/React.createElement("div", {
    className: cn("".concat(prefixCls, "-modal-content"), _defineProperty({}, "".concat(prefixCls, "-modal-content-no-title"), !title)),
    style: width ? {
      width: width
    } : undefined
  }, !!title && /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-header")
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-body")
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-modal-body-box")
  }, typeof children === 'function' ? children(onOk, onCancel) : children)), renderFooter(), renderedCloseCorner())));
}

export default Modal;
